import React, { PropsWithChildren, ReactNode } from 'react';
import { GraphQLSchema, OperationDefinitionNode, ValidationRule, FragmentDefinitionNode, DocumentNode, GraphQLError } from 'graphql';
import { VariableToType } from 'graphql-language-service';
import type { ResponseTooltipType } from '@graphiql/react';
import { ToolbarGroup } from './ToolbarGroup';
import { ToolbarMenu } from './ToolbarMenu';
import { GetDefaultFieldNamesFn } from '../utility/fillLeafs';
import type { Fetcher, Unsubscribable } from '@graphiql/toolkit';
export declare type Maybe<T> = T | null | undefined;
export declare type GraphiQLToolbarConfig = {
    additionalContent?: React.ReactNode;
};
export declare type GraphiQLProps = {
    fetcher: Fetcher;
    schema?: GraphQLSchema | null;
    validationRules?: ValidationRule[];
    query?: string;
    variables?: string;
    headers?: string;
    operationName?: string;
    response?: string;
    storage?: Storage;
    defaultQuery?: string;
    defaultVariableEditorOpen?: boolean;
    defaultSecondaryEditorOpen?: boolean;
    headerEditorEnabled?: boolean;
    shouldPersistHeaders?: boolean;
    externalFragments?: string | FragmentDefinitionNode[];
    onCopyQuery?: (query?: string) => void;
    onEditQuery?: (query?: string, documentAST?: DocumentNode) => void;
    onEditVariables?: (value: string) => void;
    onEditHeaders?: (value: string) => void;
    onEditOperationName?: (operationName: string) => void;
    onToggleDocs?: (docExplorerOpen: boolean) => void;
    getDefaultFieldNames?: GetDefaultFieldNamesFn;
    editorTheme?: string;
    onToggleHistory?: (historyPaneOpen: boolean) => void;
    ResultsTooltip?: ResponseTooltipType;
    dangerouslyAssumeSchemaIsValid?: boolean;
    inputValueDeprecation?: boolean;
    schemaDescription?: boolean;
    introspectionQueryName?: string;
    readOnly?: boolean;
    docExplorerOpen?: boolean;
    toolbar?: GraphiQLToolbarConfig;
    maxHistoryLength?: number;
    onSchemaChange?: (schema: GraphQLSchema) => void;
    beforeTopBarContent?: React.ReactElement | null;
    tabs?: boolean | {
        onTabChange?: (tab: TabsState) => void;
    };
    children?: ReactNode;
};
export declare type GraphiQLState = {
    schema?: GraphQLSchema | null;
    query?: string;
    operationName?: string;
    docExplorerOpen: boolean;
    response?: string;
    editorFlex: number;
    secondaryEditorOpen: boolean;
    secondaryEditorHeight: number;
    variableEditorActive: boolean;
    headerEditorActive: boolean;
    headerEditorEnabled: boolean;
    shouldPersistHeaders: boolean;
    historyPaneOpen: boolean;
    schemaErrors?: readonly GraphQLError[];
    docExplorerWidth: number;
    isWaitingForResponse: boolean;
    subscription?: Unsubscribable | null;
    variableToType?: VariableToType;
    operations?: OperationDefinitionNode[];
    documentAST?: DocumentNode;
    maxHistoryLength: number;
    tabs: TabsState;
};
declare type TabState = {
    id: string;
    hash: string;
    title: string;
    query: string | undefined;
    variables: string | undefined;
    headers: string | undefined;
    operationName: string | undefined;
    response: string | undefined;
};
declare type TabsState = {
    activeTabIndex: number;
    tabs: Array<TabState>;
};
export declare function GraphiQL(props: GraphiQLProps): JSX.Element;
export declare namespace GraphiQL {
    var formatResult: (result: any) => string;
    var formatError: (error: any) => string;
    var Logo: typeof GraphiQLLogo;
    var Toolbar: typeof GraphiQLToolbar;
    var Footer: typeof GraphiQLFooter;
    var QueryEditor: typeof import("./QueryEditor").QueryEditor;
    var VariableEditor: typeof import("./VariableEditor").VariableEditor;
    var HeaderEditor: typeof import("./HeaderEditor").HeaderEditor;
    var ResultViewer: typeof import("./ResultViewer").ResultViewer;
    var Button: typeof import("./ToolbarButton").ToolbarButton;
    var ToolbarButton: typeof import("./ToolbarButton").ToolbarButton;
    var Group: typeof ToolbarGroup;
    var Menu: typeof ToolbarMenu;
    var MenuItem: React.FC<{
        onSelect: () => void;
        title: string;
        label: string;
    }>;
}
declare function GraphiQLLogo<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLLogo {
    var displayName: string;
}
declare function GraphiQLToolbar<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLToolbar {
    var displayName: string;
}
declare function GraphiQLFooter<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLFooter {
    var displayName: string;
}
export {};
//# sourceMappingURL=GraphiQL.d.ts.map